<?php
/**
 * Argentinian provinces
 *
 * @author   WooThemes
 * @category i18n
 * @package  WooCommerce/i18n
 * @version  2.4.0
 */
global $states;

$states['AR'] = array(
	'C' => __( 'Ciudad Aut&oacute;noma de Buenos Aires', 'woocommerce' ),
	'B' => __( 'Buenos Aires', 'woocommerce' ),
	'K' => __( 'Catamarca', 'woocommerce' ),
	'H' => __( 'Chaco', 'woocommerce' ),
	'U' => __( 'Chubut', 'woocommerce' ),
	'X' => __( 'C&oacute;rdoba', 'woocommerce' ),
	'W' => __( 'Corrientes', 'woocommerce' ),
	'E' => __( 'Entre R&iacute;os', 'woocommerce' ),
	'P' => __( 'Formosa', 'woocommerce' ),
	'Y' => __( 'Jujuy', 'woocommerce' ),
	'L' => __( 'La Pampa', 'woocommerce' ),
	'F' => __( 'La Rioja', 'woocommerce' ),
	'M' => __( 'Mendoza', 'woocommerce' ),
	'N' => __( 'Misiones', 'woocommerce' ),
	'Q' => __( 'Neuqu&eacute;n', 'woocommerce' ),
	'R' => __( 'R&iacute;o Negro', 'woocommerce' ),
	'A' => __( 'Salta', 'woocommerce' ),
	'J' => __( 'San Juan', 'woocommerce' ),
	'D' => __( 'San Luis', 'woocommerce' ),
	'Z' => __( 'Santa Cruz', 'woocommerce' ),
	'S' => __( 'Santa Fe', 'woocommerce' ),
	'G' => __( 'Santiago del Estero', 'woocommerce' ),
	'V' => __( 'Tierra del Fuego', 'woocommerce' ),
	'T' => __( 'Tucum&aacute;n', 'woocommerce' )
);
