body {
	margin: 100px auto 24px;
	box-shadow: none;
	background: #f1f1f1;
	padding: 0;
}
#wc-logo {
	border: 0;
	margin: 0 0 24px;
	padding: 0;
	text-align: center;
	img {
		max-width: 50%;
	}
}
.wc-auth-content {
	box-shadow: 0 1px 3px rgba(0,0,0,0.13);
	padding: 24px 24px 0;
	background: #fff;
	overflow: hidden;
	zoom: 1;
	h1, h2, h3, table {
		margin: 0 0 24px;
		border: 0;
		padding: 0;
		color: #666;
		clear: none;
	}
	p, ul {
		margin: 0 0 24px;
		font-size: 1em;
		line-height: 1.75em;
		color: #666;
	}
	p {
		padding: 0;
	}
	a {
		color: #A16696;
		&:hover, &:focus {
			color: #111;
		}
	}
	.wc-auth-login {
		label {
			display: block;
			margin-bottom: .5em;
			color: #999;
		}
		input {
			font-size: 1.3em;
			padding: .5em;
			width: 100%;
			box-sizing: border-box;
		}
		.wc-auth-actions {
			padding: 0;
			.wc-auth-login-button {
				width: 100%;
				float: none;
			}
		}
	}
}
.wc-auth-permissions {
	padding: 0;
	list-style: disc inside;
	li {
		font-size: 1em;
	}
}
.wc-auth-logged-in-as {
	border-bottom: 2px solid #eee;
	background: #f5f5f5;
	padding: 0 1em 0 0;
	margin: 0 0 24px;
	line-height: 70px;
	p {
		margin: 0;
		line-height: 70px;
	}
	img {
		float: left;
		height: 70px;
		margin: 0 1em 0 0;
	}
	.wc-auth-logout {
		float: right;
	}
}
.wc-auth .wc-auth-actions {
	overflow: hidden;
	padding-left: 24px;
	.button {
		float: right;
		font-size: 1.25em;
		padding: 1em 2em;
		line-height: 1em;
		height: auto;
		width: 50%;
		box-sizing: border-box;
		text-align: center;
		background: #f7f7f7;
		border: 1px solid #d7d7d7;
		color: #777;
		border-bottom-width: 2px;
		&:hover, &:focus {
			background: #fcfcfc;
		}
	}
	.button-primary {
		float: right;
		opacity: 1;
		-webkit-box-shadow: inset 0 1px 0 rgba( 255, 255, 255, 0.2 ), 0 1px 0 rgba( 0, 0, 0, 0.15 );
		box-shadow: inset 0 1px 0 rgba( 255, 255, 255, 0.2 ), 0 1px 0 rgba( 0, 0, 0, 0.15 );
		background: #AD6EA1;
		border-color: #A16696;
		color: #fff;
		&:hover, &:focus {
			background: #B472A8;
			color: #fff;
		}
	}
	.wc-auth-approve {
		float: right;
	}
	.wc-auth-deny {
		float: left;
		margin-left: -24px;
	}
}