body {
	margin: 100px auto 24px;
	box-shadow: none;
	background: #f1f1f1;
	padding: 0;
}
#wc-logo {
	border: 0;
	margin: 0 0 24px;
	padding: 0;
	text-align: center;
	img {
		max-width: 50%;
	}
}
.wc-setup-content {
	box-shadow: 0 1px 3px rgba(0,0,0,0.13);
	padding: 24px 24px 0;
	background: #fff;
	overflow: hidden;
	zoom: 1;

	h1, h2, h3, table {
		margin: 0 0 24px;
		border: 0;
		padding: 0;
		color: #666;
		clear: none;
	}
	p {
		margin: 0 0 24px;
		font-size: 1em;
		line-height: 1.75em;
		color: #666;
	}
	table {
		font-size: 1em;
		line-height: 1.75em;
		color: #666;
	}
	a {
		color: #A16696;
		&:hover, &:focus {
			color: #111;
		}
	}
	.form-table {
		th {
			width: 35%;
			vertical-align: top;
			font-weight: normal;
		}
		td {
			vertical-align: top;
			select, input {
				width: 100%;
				box-sizing: border-box;
			}
			input[size] {
				width: auto;
			}
			.description {
				line-height: 1.5em;
				display: block;
				margin-top: .25em;
				color: #999;
				font-style: italic;
			}
			.input-checkbox, .input-radio {
				width: auto;
				box-sizing: inherit;
				padding: inherit;
				margin: 0 .5em 0 0;
				box-shadow: none;
			}
		}
		.section_title {
			td {
				padding: 0;
				h2, p {
					margin: 12px 0 0;
				}
			}
		}
		th, td {
			padding: 12px 0;
			margin: 0;
			border: 0;
			&:first-child {
				padding-right: 1em;
			}
		}
		table.tax-rates {
			width: 100%;
			font-size: .92em;
			th {
				padding: 0;
				text-align: center;
				width: auto;
				vertical-align: middle;
			}
			td {
				border: 1px solid #eee;
				padding: 6px 6px;
				text-align: center;
				vertical-align: middle;
				input {
					outline: 0;
					border: 0;
					padding: 0;
					box-shadow: none;
					text-align: center;
				}
				&.sort {
					cursor: move;
					color: #ccc;
					&:before {
						content: "\f333";
						font-family: 'dashicons';
					}
				}
			}
			.add {
				padding: 1em 0 0 1em;
				line-height: 1em;
				font-size: 1em;
				width: 0;
				margin: 6px 0 0;
				height: 0;
				overflow: hidden;
				position: relative;
				display: inline-block;
				&:before {
					content: "\f502";
					font-family: 'dashicons';
					position: absolute;
					left: 0;
					top: 0;
				}
			}
			.remove {
				padding: 1em 0 0 1em;
				line-height: 1em;
				font-size: 1em;
				width: 0;
				margin: 0;
				height: 0;
				overflow: hidden;
				position: relative;
				display: inline-block;
				&:before {
					content: "\f182";
					font-family: 'dashicons';
					position: absolute;
					left: 0;
					top: 0;
				}
			}
		}
	}
	.wc-setup-pages {
		width: 100%;
		border-top: 1px solid #eee;
		thead th {
			display: none;
		}
		.page-name {
			width: 30%;
			font-weight: bold;
		}
		th, td {
			padding: 14px 0;
			border-bottom: 1px solid #eee;
			&:first-child {
				padding-right: 9px;
			}
		}
		th {
			padding-top: 0;
		}
		.page-options {
			p {
				color: #777;
				margin: 6px 0 0 24px;
				line-height: 1.75em;
				input {
					vertical-align: middle;
					margin: 1px 0 0 0;
					height: 1.75em;
					width: 1.75em;
					line-height: 1.75em;
				}
				label {
					line-height: 1;
				}
			}
		}
	}
	@media screen and (max-width: 782px) {
		.form-table {
			tbody {
				th {
					width: auto;
				}
			}
		}
	}
	.twitter-share-button {
		float: right;
	}
	.wc-setup-next-steps {
		overflow: hidden;
		margin: 0 0 24px;
		h2 {
			margin-bottom: 12px;
		}
		.wc-setup-next-steps-first {
			float: left;
			width: 50%;
			box-sizing: border-box;
		}
		.wc-setup-next-steps-last {
			float: right;
			width: 50%;
			box-sizing: border-box;
		}
		ul {
			padding: 0 2em 0 0;
			list-style: none outside;
			margin: 0 0 -.75em;
			li a {
				display: block;
				padding: 0 0 .75em;
			}
			.setup-product {
				a {
					text-align: center;
					font-size: 1em;
					padding: 1em;
					line-height: 1.75em;
					height: auto;
					margin: 0 0 .75em;
					opacity: 1;
					background-color: #A16696;
					border-color: #A16696;
					-webkit-box-shadow: inset 0 1px 0 rgba( 255, 255, 255, 0.2 ), 0 1px 0 rgba( 0, 0, 0, 0.15 );
					box-shadow: inset 0 1px 0 rgba( 255, 255, 255, 0.2 ), 0 1px 0 rgba( 0, 0, 0, 0.15 );
				}
			}
			li a:before {
				color: #82878c;
				font: normal 20px/1 'dashicons';
				speak: none;
				display: inline-block;
				padding: 0 10px 0 0;
				top: 1px;
				position: relative;
				-webkit-font-smoothing: antialiased;
				-moz-osx-font-smoothing: grayscale;
				text-decoration: none !important;
				vertical-align: top;
			}
			.learn-more a:before {
				content: "\f105";
			}
			.video-walkthrough a:before {
				content: "\f126";
			}
			.sidekick a:before {
				content: "\f118";
			}
			.newsletter a:before {
				content: "\f465";
			}
		}
	}
	.woocommerce-tracker {
		padding: 24px 24px 0;
		margin: 0 0 24px 0;
		background: #f5f5f5;
	}
}
.wc-setup-steps {
	padding: 0 0 24px;
	margin: 0;
	list-style: none outside;
	overflow: hidden;
	color: #ccc;
	li {
		width: 20%;
		float: left;
		padding: 0 0 1em;
		margin: 0;
		text-align: center;
		position: relative;
		border-bottom: 4px solid #ccc;
		line-height: 1;
	}
	li:before {
		content: "";
		border: 4px solid #ccc;
		border-radius: 100%;
		width: 4px;
		height: 4px;
		position: absolute;
		bottom: 0;
		left: 50%;
		margin-left: -6px;
		margin-bottom: -8px;
		background: #fff;
	}
	li.active {
		border-color: #A16696;
		color: #A16696;
		&:before {
			border-color: #A16696;
		}
	}
	li.done {
		border-color: #A16696;
		color: #A16696;
		&:before {
			border-color: #A16696;
			background: #A16696;
		}
	}
}
.wc-setup .wc-setup-actions {
	overflow: hidden;
	.button {
		float: right;
		font-size: 1.25em;
		padding: .5em 1em;
		line-height: 1em;
		margin-right: .5em;
		height: auto;
	}
	.button-primary {
		margin: 0;
		float: right;
		opacity: 1;
		background-color: #A16696;
		border-color: #A16696;
		-webkit-box-shadow: inset 0 1px 0 rgba( 255, 255, 255, 0.2 ), 0 1px 0 rgba( 0, 0, 0, 0.15 );
		box-shadow: inset 0 1px 0 rgba( 255, 255, 255, 0.2 ), 0 1px 0 rgba( 0, 0, 0, 0.15 );
	}
}
.wc-return-to-dashboard {
	font-size: 0.85em;
	color: #b5b5b5;
	margin: 1.18em 0;
	display: block;
	text-align: center;
}